==> ppcboot-0.5.2.tar.gz: ppcboot-0.5.2/include/command.h <==
/*
 * (C) Copyright 2000
 * Wolfgang Denk, DENX Software Engineering, wd@denx.de.
 *
 * See file CREDITS for list of people who contributed to this
 * project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*
 *  Definitions for Command Processor
 */
#ifndef __COMMAND_H
#define __COMMAND_H

#ifndef NULL
#define NULL	0
#endif

#ifndef	__ASSEMBLY__
/*
 * Monitor Command Table
 */

struct cmd_tbl_s {
	char		*name;		/* Command Name			*/
	int		lmin;		/* minimum abbreviated length	*/
	int		maxargs;	/* maximum number of arguments	*/
					/* Implementation function	*/
	void		(*cmd)(struct cmd_tbl_s *, bd_t *, int, int, char *[]);
	char		*usage;		/* Usage message	(short)	*/
#ifdef	CFG_LONGHELP
	char		*help;		/* Help  message	(long)	*/
#endif
};

typedef struct cmd_tbl_s	cmd_tbl_t;

extern	cmd_tbl_t cmd_tbl[];

#ifdef	CFG_LONGHELP
#define	MK_CMD_TBL_ENTRY(name,lmin,maxargs,cmd,usage,help)	\
				{ name, lmin, maxargs, cmd, usage, help }
#else	/* no help info */
#define	MK_CMD_TBL_ENTRY(name,lmin,maxargs,cmd,usage,help)	\
				{ name, lmin, maxargs, cmd, usage }
#endif



/*
 * Monitor Command
 *
 * All commands use a common argument format:
 *
 * void function (cmd_tbl_t *cmdtp, bd_t *bd, int flag, int argc, char *argv[]);
 */

typedef	void 	command_t (cmd_tbl_t *, bd_t *, int, int, char *[]);

#endif	/* __ASSEMBLY__ */

/*
 * Command Flags:
 */
#define CMD_FLAG_REPEAT		0x0001	/* repeat same command as before	*/

/*
 * Configurable monitor commands
 */
#define CFG_CMD_BDI	0x00000001	/* bdinfo			*/
#define CFG_CMD_LOADS	0x00000002	/* loads			*/
#define CFG_CMD_LOADB	0x00000004	/* loadb			*/
#define CFG_CMD_IMI	0x00000008	/* iminfo			*/
#define CFG_CMD_CACHE	0x00000010	/* icache, dcache		*/
#define CFG_CMD_FLASH	0x00000020	/* flinfo, erase, protect	*/
#define CFG_CMD_MEMORY	0x00000040	/* md, mm, nm, mw, cp, cmp,	*/
					/* crc, base, loop, mtest	*/
#define CFG_CMD_NET	0x00000080	/* bootp, tftpboot, rarpboot	*/
#define CFG_CMD_ENV	0x00000100	/* saveenv			*/
#define CFG_CMD_KGDB	0x00000200	/* kgdb				*/

#define CFG_CMD_ALL	0xFFFFFFFF	/* ALL commands			*/

/* Default configuration: everything but KGDB (which is quite big)
 */
#define	CONFIG_CMD_DFL	(CFG_CMD_ALL & ~(CFG_CMD_KGDB))

#ifndef CONFIG_COMMANDS
#define CONFIG_COMMANDS	CONFIG_CMD_DFL
#endif

#endif	/* __COMMAND_H */

==> ppcboot-0.5.3.tar.gz: ppcboot-0.5.3/include/command.h <==
/*
 * (C) Copyright 2000
 * Wolfgang Denk, DENX Software Engineering, wd@denx.de.
 *
 * See file CREDITS for list of people who contributed to this
 * project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*
 *  Definitions for Command Processor
 */
#ifndef __COMMAND_H
#define __COMMAND_H

#ifndef NULL
#define NULL	0
#endif

#ifndef	__ASSEMBLY__
/*
 * Monitor Command Table
 */

struct cmd_tbl_s {
	char		*name;		/* Command Name			*/
	int		lmin;		/* minimum abbreviated length	*/
	int		maxargs;	/* maximum number of arguments	*/
					/* Implementation function	*/
	void		(*cmd)(struct cmd_tbl_s *, bd_t *, int, int, char *[]);
	char		*usage;		/* Usage message	(short)	*/
#ifdef	CFG_LONGHELP
	char		*help;		/* Help  message	(long)	*/
#endif
};

typedef struct cmd_tbl_s	cmd_tbl_t;

extern	cmd_tbl_t cmd_tbl[];

#ifdef	CFG_LONGHELP
#define	MK_CMD_TBL_ENTRY(name,lmin,maxargs,cmd,usage,help)	\
				{ name, lmin, maxargs, cmd, usage, help }
#else	/* no help info */
#define	MK_CMD_TBL_ENTRY(name,lmin,maxargs,cmd,usage,help)	\
				{ name, lmin, maxargs, cmd, usage }
#endif



/*
 * Monitor Command
 *
 * All commands use a common argument format:
 *
 * void function (cmd_tbl_t *cmdtp, bd_t *bd, int flag, int argc, char *argv[]);
 */

typedef	void 	command_t (cmd_tbl_t *, bd_t *, int, int, char *[]);

#endif	/* __ASSEMBLY__ */

/*
 * Command Flags:
 */
#define CMD_FLAG_REPEAT		0x0001	/* repeat same command as before	*/

/*
 * Configurable monitor commands
 */
#define CFG_CMD_BDI	0x00000001	/* bdinfo			*/
#define CFG_CMD_LOADS	0x00000002	/* loads			*/
#define CFG_CMD_LOADB	0x00000004	/* loadb			*/
#define CFG_CMD_IMI	0x00000008	/* iminfo			*/
#define CFG_CMD_CACHE	0x00000010	/* icache, dcache		*/
#define CFG_CMD_FLASH	0x00000020	/* flinfo, erase, protect	*/
#define CFG_CMD_MEMORY	0x00000040	/* md, mm, nm, mw, cp, cmp,	*/
					/* crc, base, loop, mtest	*/
#define CFG_CMD_NET	0x00000080	/* bootp, tftpboot, rarpboot	*/
#define CFG_CMD_ENV	0x00000100	/* saveenv			*/
#define CFG_CMD_KGDB	0x00000200	/* kgdb				*/
#define	CFG_CMD_IDE	0x00000400	/* IDE harddisk support		*/
#define	CFG_CMD_PCI	0x00000800	/* pciinfo			*/
#define	CFG_CMD_IRQ	0x00001000	/* irqinfo			*/
#define CFG_CMD_BOOTD	0x00002000	/* bootd			*/

#define CFG_CMD_ALL	0xFFFFFFFF	/* ALL commands			*/

/* Commands that are considered "non-standard" for some reason
 * (memory hogs, requires special hardware, not fully tested, etc.)
 */
#define CFG_CMD_NONSTD	(CFG_CMD_KGDB | CFG_CMD_IDE | CFG_CMD_PCI | CFG_CMD_IRQ)

/* Default configuration
 */
#define	CONFIG_CMD_DFL	(CFG_CMD_ALL & ~CFG_CMD_NONSTD)

#ifndef CONFIG_COMMANDS
#define CONFIG_COMMANDS	CONFIG_CMD_DFL
#endif

#endif	/* __COMMAND_H */
